@@ -133,7 +133,7 @@
 #'`methods(class = "mvgam")` for an overview on available methods
 #'
 #'@examples
-#'\donttest{
+#'\dontrun{
 #' # ========================================================================
 #' # Example 1: Basic JSDGAM with Portal Data
 #' # ========================================================================
@@ -429,11 +429,9 @@
 #'   scale_color_viridis_c() +
 #'   theme_classic()
 #'
-#' \dontshow{
-#' # For R CMD check: make sure any open connections are closed afterward
-#'   closeAllConnections()
+#' # Not needed for general use; cleans up connections for automated testing
+#' closeAllConnections()
 #' }
-#'}
 #'@export
 jsdgam = function(
   formula,
@@ -734,7 +732,9 @@ jsdgam = function(
     # Check if cmdstan is accessible; if not, use rstan
     if (backend == 'cmdstanr') {
       if (!requireNamespace('cmdstanr', quietly = TRUE)) {
-        warning('cmdstanr library not found. Defaulting to rstan')
+        if (silent < 2) {
+          message('cmdstanr library not found; defaulting to rstan')
+        }
         use_cmdstan <- FALSE
       } else {
         use_cmdstan <- TRUE
