@@ -409,7 +409,7 @@
 #' overview on available methods.
 #'
 #' @examples
-#' \donttest{
+#' \dontrun{
 #' # =============================================================================
 #' # Basic Multi-Series Time Series Modeling
 #' # =============================================================================
@@ -841,11 +841,9 @@
 #'   type = 'expected'
 #' )
 #'
-#' \dontshow{
-#' # For R CMD check: make sure any open connections are closed afterward
+#' # Not needed for general use; cleans up connections for automated testing
 #' closeAllConnections()
 #' }
-#' }
 #' @export
 
 mvgam <- function(
@@ -2462,7 +2460,9 @@ mvgam <- function(
       # Check if cmdstan is accessible; if not, use rstan
       if (backend == "cmdstanr") {
         if (!requireNamespace("cmdstanr", quietly = TRUE)) {
-          warning("cmdstanr library not found. Defaulting to rstan")
+          if (silent < 2) {
+            message("cmdstanr library not found; defaulting to rstan")
+          }
           use_cmdstan <- FALSE
         } else {
           use_cmdstan <- TRUE
